@@ -30,6 +30,7 @@ OC.L10N.register(
     "Folder name" : "Dossiers Numm:",
     "Go back" : "Zeréckgoen",
     "Folder exists already!" : "Dësen Dossier gëtt et schonns!",
+    "Credentials" : "Credentials",
     "Username" : "Benotzernumm",
     "Password" : "Passwuert",
     "New Folder" : "Neien Dossier",
@@ -37,6 +38,7 @@ OC.L10N.register(
     "Explore" : "Erfuerschen",
     "Rename" : "Ëm-benennen",
     "Menu" : "Menü",
+    "Delete" : "Läschen",
     "Dismiss" : "Verworf",
     "Collapse" : "Zesumme falen",
     "Deleted folder" : "Dossier läschen",
