@@ -72,8 +72,11 @@ OC.L10N.register(
     "Undo delete feed" : "Atšaukti kanalo ištrynimą",
     "Rename" : "Pervadinti",
     "Menu" : "Meniu",
+    "Mark read" : "Žymėti kaip skaitytą",
     "Unpin from top" : "Atsegti nuo viršaus",
     "Pin to top" : "Prisegti viršuje",
+    "Newest first" : "Naujausi pirma",
+    "Oldest first" : "Seniausi pirma",
     "Default order" : "Numatytoji tvarka",
     "Open feed URL" : "Atverti kanalo URL",
     "Delete" : "Ištrinti",
