@@ -4,6 +4,7 @@ OC.L10N.register(
     "Can not add feed: Exists already" : "Не можам да додадам фид: Веќе постои",
     "Articles without feed" : "Статии без фид",
     "Can not add folder: Exists already" : "Не можам да додадам папка: Веќе постои",
+    "News" : "Новости",
     "Saved" : "Снимено",
     "Download" : "Преземи",
     "Close" : "Затвори",
@@ -18,11 +19,17 @@ OC.L10N.register(
     "Folder" : "Папка",
     "New folder" : "Нова папка",
     "Folder name" : "Име на папка",
+    "Go back" : "Назад",
     "Credentials" : "Акредитиви",
     "Username" : "Корисничко име",
     "Password" : "Лозинка",
     "Create" : "Создај",
     "Rename" : "Преименувај",
+    "Mark read" : "Означи како прочитано",
+    "Newest first" : "Новите прво",
+    "Oldest first" : "Старите прво",
+    "Delete" : "Избриши",
+    "Dismiss" : "Отфрли",
     "Collapse" : "Собери",
     "Starred" : "Со ѕвезда",
     "Unread articles" : "Непрочитани статии",
@@ -35,6 +42,7 @@ OC.L10N.register(
     "Error when importing: file does not contain valid JSON" : "Грешка при импортирање: датотеката не содржи валиден JSON",
     "Help" : "Помош",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
-    "Documentation" : "Документација"
+    "Documentation" : "Документација",
+    "Report a bug" : "Пријави грешка"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
