@@ -10,10 +10,12 @@ OC.L10N.register(
     "Refresh" : "Refresh",
     "Web address" : "Alamat sesawang",
     "Folder" : "Folder",
+    "Credentials" : "Credentials",
     "Username" : "Nama pengguna",
     "Password" : "Kata laluan",
     "Create" : "Buat",
     "Rename" : "Namakan",
+    "Delete" : "Padam",
     "Settings" : "Tetapan",
     "Import" : "Import",
     "Export" : "Export",
