@@ -12,10 +12,12 @@ OC.L10N.register(
     "Web address" : "අන්තර්ජාල ලිපිනය",
     "Folder" : "ෆෝල්ඩරය",
     "Folder name" : "ෆොල්ඩරයේ නම",
+    "Credentials" : "Credentials",
     "Username" : "පරිශීලක නම",
     "Password" : "මුර පදය",
     "Create" : "තනන්න",
     "Rename" : "නැවත නම් කරන්න",
+    "Delete" : "ඉවත් කරන්න",
     "Collapse" : "හකුළන්න",
     "Starred" : "තරු දැමු",
     "Settings" : "සිටුවම්",
