@@ -4,15 +4,15 @@ OC.L10N.register(
     "Request failed, network connection unavailable!" : "Zahteva je spodletela. Omrežna povezava trenutno ni na voljo!",
     "Request unauthorized. Are you logged in?" : "Zahteva ni ustrezno overjena. Ali ste prijavljeni?",
     "Request forbidden. Are you an admin?" : "Zahteva je zavrnjena. Ali ste prijavljeni kot skrbnik?",
-    "Token expired or app not enabled! Reload the page!" : "Ključ je potekel ali pa program ni omogočen! Poskusite osvežiti stran!",
-    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Interna napaka strežnika! Preveri data/nextcloud.log datoteko za dodatne informacije!",
-    "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahteva ni uspela, Nextcloud je trenutno v servisnem načinu!",
-    "Can not add feed: Exists already" : "Vira ni mogoče dodati: ta že obstaja",
+    "Token expired or app not enabled! Reload the page!" : "Žeton je potekel ali pa program ni omogočen! Poskusite osvežiti stran!",
+    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Notranja napaka strežnika! Preverite datoteko data/nextcloud.log za podrobnosti!",
+    "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahteva je spodletela! Okolje Nextcloud je trenutno v vzdrževalnem načinu!",
+    "Can not add feed: Exists already" : "Vira ni mogoče dodati: vir že obstaja",
     "Articles without feed" : "Prispevki brez virov",
-    "Can not add folder: Exists already" : "Ni mogoče dodati mape: mapa že obstaja.",
+    "Can not add folder: Exists already" : "Mape ni mogoče dodati: mapa že obstaja",
     "News" : "Novice",
     "An RSS/Atom feed reader" : "Bralnik virov RSS/Atom",
-    "Use system cron for updates" : "Uporabi sistemski ukaz 'cron' za posodobitve",
+    "Use system cron for updates" : "Za posodobitve uporabi sistemski program »cron«",
     "Disable this if you run a custom updater such as the Python updater included in the app" : "Možnost onemogočite, če uporabljate posodabljalnik po meri, kot je na primer posodabljalnik Python, vključen v programski paket",
     "Purge interval" : "Časovni razmik odstranjevanja",
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Najkrajši čas, po katerem bodo viri in mape odstranjeni iz podatkovne zbirke. Vrednosti pod 60 sekundami so prezrte.",
@@ -94,6 +94,7 @@ OC.L10N.register(
     "Default order" : "Privzeta razvrstitev",
     "Enable full text" : "Omogoči polno besedilo",
     "Disable full text" : "Omogoči polno besedilo",
+    "Unread updated" : "Neprebrano je posodobljeno",
     "Ignore updated" : "Prezri posodobljeno",
     "Delete" : "Izbriši",
     "Dismiss" : "Opusti",
